import java.io.File;
import java.util.HashMap;
import java.util.Scanner;

/**
 * A helper class for performing sentiment analysis
 * 
 * @author Joel; utilizes data from EECS Berkeley 61a course
 * @version Sp15
 */
public class Sentiments
{
    /**
     * Returns a value representing the amount of positive or negative sentiment in the given word.
     * This is a number between 1 (totally positive) and -1 (totally negative).
     * Caputalization and punctuation in words is ignored
     * @param word A word to get the sentiment of
     * @return A value between 1 (totally positive) and -1 (totally negative).
     */
    public static double getWordSentiment(String word)
    {
        if(sentimentData == null) //if we don't have a table
        {
            //System.out.println("DEBUG: loading sentiment data");
            sentimentData = loadWordSentiments(); //load it
        }
    
        word = word.toLowerCase().replaceAll("\\W+",""); //make lower, strip non word
        
        if(sentimentData.get(word) != null) //if word is in the dataset
            return sentimentData.get(word); //return that word's weight
        else
            return 0; //otherwise no weight
    }
    
    /**
     * Singleton to hold the sentiment data (to avoid double-loading)
     */
    private static HashMap<String,Double> sentimentData; 

    /**
     * Loads and processes the word sentiment data
     */
    private static HashMap<String,Double> loadWordSentiments()
    {
        HashMap<String,Double> sentiments = new HashMap<String,Double>(); //store in a HashMap (see CS261)
        try{
            File f = new File("sentiments.csv"); //Berkeley's sentiments file
            Scanner sc = new Scanner(f);
            while(sc.hasNextLine()) //read the file
            {
                String line = sc.nextLine();
                int comma = line.indexOf(',');
                String word = line.substring(0,comma); //grab the word
                double weight = Double.parseDouble(line.substring(comma+1)); //grab the weight
                sentiments.put(word, weight);
            }
            sc.close(); //close file when done
        }
        catch(Exception e) //in case something goes wrong
        {
            System.out.println("Error loading word sentiment data: "+e);
        }
        
        return sentiments;
    }

    private Sentiments(){} //no constructor
}
